@@ -1261,7 +1261,10 @@ WHERE
         cron_string = self.cron_expression_to_string(cron_input)
         cron_command = '(crontab -l 2> /dev/null; echo "' + cron_string + ' ' + command + '  # jaaql__' + application + '") | crontab -'
         if self.is_container:
-            subprocess.run(cron_command, check=True, shell=True, timeout=5)
+            try:
+                subprocess.run(cron_command, check=True, shell=True, timeout=5, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            except subprocess.CalledProcessError as e:
+                raise CronExpressionError("Error with the cron expression. Input: " + json.dumps(cron_input) + ", evaluated to cron expression: '" + cron_string + "', Stdout:\n" + (e.stdout.decode() if e.stdout else "None") + "\n\nStderr: " + (e.stderr.decode() if e.stderr else "None"))
         else:
             print(cron_command)
             print("Cron not supported in debugging mode", file=sys.stderr)
